..
    This file is part of hepcrawl.
    Copyright (C) 2015, 2016, 2017 CERN.

    hepcrawl is a free software; you can redistribute it and/or modify it
    under the terms of the Revised BSD License; see LICENSE file for
    more details.

.. raw:: html

    <p style="height:22px; margin:0 0 0 2em; float:right">
        <a href="https://travis-ci.org/inspirehep/hepcrawl">
            <img src="https://travis-ci.org/inspirehep/hepcrawl.png?branch=master"
                 alt="travis-ci badge"/>
        </a>
        <a href="https://coveralls.io/r/inspirehep/hepcrawl">
            <img src="https://coveralls.io/repos/inspirehep/hepcrawl/badge.png?branch=master"
                 alt="coveralls.io badge"/>
        </a>
    </p>


.. include:: ../README.rst


User's Guide
------------

This part of the documentation will show you how to get started in using
HEPCrawl.

.. toctree::
   :maxdepth: 2

   overview
   installation
   operations
   contributing
   guide
   inspire_crawler


API Reference
-------------

If you are looking for information on a specific function, class or method,
this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   _source/hepcrawl.rst
   spiders

Additional Notes
----------------

Notes on how to contribute, legal information and changes are here for the
interested.

.. toctree::
   :maxdepth: 1

   changes
   releasenotes
   license
   authors


Happy crawling!

| INSPIRE Development Team
|   Email: feedback@inspirehep.net
|   Twitter: http://twitter.com/inspirehep
|   GitHub: http://github.com/inspirehep
|   URL: http://inspirehep.net
